@@ -3,6 +3,8 @@ from ev3sim.devices.base import IDeviceInteractor, Device
 from ev3sim.devices.compass.base import CompassSensorMixin
 from ev3sim.objects.utils import local_space_to_world_space
 from ev3sim.simulation.loader import ScriptLoader
+from ev3sim.simulation.randomisation import Randomiser
+from ev3sim.devices.utils import NearestValue, CyclicMixin, RandomDistributionMixin
 
 
 class CompassInteractor(IDeviceInteractor):
@@ -27,6 +29,14 @@ class CompassInteractor(IDeviceInteractor):
                 obj.rotation = self.physical_object.rotation + self.relative_rotation
 
 
+class CompassValueDistribution(CyclicMixin, RandomDistributionMixin, NearestValue):
+    pass
+
+
+class CompassValueDistributionNoRandom(CyclicMixin, NearestValue):
+    pass
+
+
 class CompassSensor(CompassSensorMixin, Device):
     """
     EV3 Compass Sensor, calculates the bearing of the device relative to some direction (which can be specified).
@@ -36,8 +46,32 @@ class CompassSensor(CompassSensorMixin, Device):
     To set the relative heading of the sensor, use `calibrate`.
     """
 
+    # Generate 31 (Really 30) static points of interest that the compass jumps to.
+    NEAREST_POINTS_NUMBER = 51
+    # The distribution variance of the nearest points
+    NEAREST_POINTS_VARIANCE = 16
+
+    # Maximum bias towards one direction, in degrees.
+    MAX_SENSOR_OFFSET = 5
+
+    def generateBias(self):
+        if ScriptLoader.RANDOMISE_SENSORS:
+            # Distribute points cyclically between 0 and 360.
+            self.dist = CompassValueDistribution(
+                0,
+                360,
+                self.NEAREST_POINTS_NUMBER,
+                self.NEAREST_POINTS_VARIANCE,
+                Randomiser.getPortRandom(self._interactor.port_key),
+            )
+            self.offset = (0.5 - self._interactor.random()) * 2 * self.MAX_SENSOR_OFFSET
+        else:
+            self.dist = CompassValueDistributionNoRandom(0, 360, self.NEAREST_POINTS_NUMBER)
+            self.offset = 0
+        self._value = 0
+
     def _calc(self):
-        self._value = int(self._getValue())
+        self._value = int(self.dist.get_closest(self._getValue() + self.offset))
 
     def value(self):
         """
