@@ -14,19 +14,19 @@ class ScriptLoader:
 
     active_scripts: List[IInteractor]
     VISUAL_TICK_RATE = 30
-    GAME_TICK_RATE = 60
+    GAME_TICK_RATE = 30
     TIME_SCALE = 1
     # TIME_SCALE simply affects the speed at which the simulation runs
     # (TIME_SCALE = 2, GAME_TICK_RATE = 30 implies 60 ticks of per actual seconds)
 
+    RANDOMISE_SENSORS = False
+
     instance: "ScriptLoader" = None
     running = True
 
     def __init__(self, **kwargs):
         ScriptLoader.instance = self
         self.robots = {}
-        for key, value in kwargs.items():
-            setattr(self, key, value)
 
     def sendEvent(self, botID, eventName, eventData):
         self.data["events"][botID].put((eventName, eventData))
@@ -137,23 +137,27 @@ class ScriptLoader:
 
 
 def runFromConfig(config, shared):
+    from collections import defaultdict
     from ev3sim.robot import initialise_bot, RobotInteractor
     from ev3sim.file_helper import find_abs
 
-    sl = ScriptLoader(**config.get("loader", {}))
+    sl = ScriptLoader()
     sl.setSharedData(shared)
     sl.active_scripts = []
     ev3sim.visual.utils.GLOBAL_COLOURS = config.get("colours", {})
+    # Keep track of index w.r.t. filename.
+    robot_paths = defaultdict(lambda: 0)
     for index, robot in enumerate(config.get("robots", [])):
         robot_path = find_abs(robot, allowed_areas=["local", "local/robots/", "package", "package/robots/"])
-        initialise_bot(config, robot_path, f"Robot-{index}")
+        initialise_bot(config, robot_path, f"Robot-{index}", robot_paths[robot_path])
+        robot_paths[robot_path] += 1
     for opt in config.get("interactors", []):
         try:
             sl.active_scripts.append(fromOptions(opt))
         except Exception as exc:
             print(f"Failed to load interactor with the following options: {opt}. Got error: {exc}")
     if sl.active_scripts:
-        sl.startUp(**config.get("screen", {}))
+        sl.startUp()
         sl.loadElements(config.get("elements", []))
         for interactor in sl.active_scripts:
             if isinstance(interactor, RobotInteractor):
